#
# Configuration file for using the gnome-print library
#
PRINT_LIBDIR="-L/usr/X11R6/lib"
PRINT_LIBS="-lgnomeprint -L/usr/X11R6/lib -L/usr/local/lib -lXpm -lgnomeui -lart_lgpl -lgdk_imlib -ltiff -ljpeg -lungif -lpng -lz -lSM -lICE -lgnome -lgnomesupport -lesd -laudiofile -lgdk_pixbuf -lgtk12 -lgdk12 -lgmodule12 -lglib12 -ldl -lintl -lxpg4 -lXext -lX11 -lm -L/usr/local/lib -lxml -lz"
PRINT_INCLUDEDIR="-I/usr/X11R6/include/gnome-1.0 -I/usr/X11R6/include/gnome-1.0 -I/usr/X11R6/include -DNEED_GNOMESUPPORT_H -I/usr/local/include -I/usr/X11R6/include/gdk-pixbuf-1.0 -I/usr/X11R6/include/gtk12 -I/usr/local/include/gnome-xml  -I/usr/X11R6/include/gdk-pixbuf-1.0 -I/usr/X11R6/include/gtk12 -I/usr/local/include -I/usr/local/include -I/usr/X11R6/include"
MODULE_VERSION="gnome-print-0.31"
